@@ -56,6 +56,7 @@
 #include <regex.h>
 
 #include "llist.h"
+#include "vector.h"
 #include "htable.h"
 #include "llist_ts.h"
 
@@ -156,9 +157,9 @@
 #define TAB                     9
 #define SPACE                   32
 
-#define KEYS_KEYLEN         3   /* length of each keybinding */
-#define KEYS_LABELEN        8   /* length of command description */
-#define KEYS_CMDS_PER_LINE  6   /* max number of commands per line */
+#define KEYS_KEYLEN         3	/* length of each keybinding */
+#define KEYS_LABELEN        8	/* length of command description */
+#define KEYS_CMDS_PER_LINE  6	/* max number of commands per line */
 
 /* Register definitions. */
 #define REG_BLACK_HOLE 37
@@ -230,49 +231,51 @@
 #define UTF8_ISCONT(ch) ((unsigned char)ch >= 0x80 && \
     (unsigned char)ch <= 0xBF)
 
+#define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
+
 #define MAX(x,y) ((x)>(y)?(x):(y))
 #define MIN(x,y) ((x)<(y)?(x):(y))
 
 enum win {
-  CAL,
-  APP,
-  TOD,
-  NOT,
-  STA,
-  KEY,
-  NBWINS
+	CAL,
+	APP,
+	TOD,
+	NOT,
+	STA,
+	KEY,
+	NBWINS
 };
 
 /* General configuration variables. */
 struct conf {
-  unsigned auto_save;
-  unsigned auto_gc;
-  unsigned periodic_save;
-  unsigned confirm_quit;
-  unsigned confirm_delete;
-  enum win default_panel;
-  unsigned compact_panels;
-  unsigned system_dialogs;
-  unsigned progress_bar;
-  const char *editor;
-  const char *pager;
-  char output_datefmt[BUFSIZ];  /* format for displaying date */
-  int input_datefmt;            /* format for reading date */
+	unsigned auto_save;
+	unsigned auto_gc;
+	unsigned periodic_save;
+	unsigned confirm_quit;
+	unsigned confirm_delete;
+	enum win default_panel;
+	unsigned compact_panels;
+	unsigned system_dialogs;
+	unsigned progress_bar;
+	const char *editor;
+	const char *pager;
+	char output_datefmt[BUFSIZ];	/* format for displaying date */
+	int input_datefmt;	/* format for reading date */
 };
 
 /* Daemon-related configuration. */
 struct dmon_conf {
-  unsigned enable;              /* launch daemon automatically when exiting */
-  unsigned log;                 /* log daemon activity */
+	unsigned enable;	/* launch daemon automatically when exiting */
+	unsigned log;		/* log daemon activity */
 };
 
 /* Input date formats. */
 enum datefmt {
-  DATEFMT_MMDDYYYY = 1,
-  DATEFMT_DDMMYYYY,
-  DATEFMT_YYYYMMDD,
-  DATEFMT_ISO,
-  DATEFMT_MAX
+	DATEFMT_MMDDYYYY = 1,
+	DATEFMT_DDMMYYYY,
+	DATEFMT_YYYYMMDD,
+	DATEFMT_ISO,
+	DATEFMT_MAX
 };
 
 #define DATE_FORMATS (DATEFMT_MAX - 1)
@@ -286,179 +289,184 @@ enum datefmt {
     (datefmt == DATEFMT_YYYYMMDD ? _("yyyy/mm/dd") : _("yyyy-mm-dd"))))
 
 struct date {
-  unsigned dd;
-  unsigned mm;
-  unsigned yyyy;
+	unsigned dd;
+	unsigned mm;
+	unsigned yyyy;
 };
 
 /* Appointment definition. */
 struct apoint {
-  long start;                   /* seconds since 1 jan 1970 */
-  long dur;                     /* duration of the appointment in seconds */
+	long start;		/* seconds since 1 jan 1970 */
+	long dur;		/* duration of the appointment in seconds */
 
 #define APOINT_NULL      0x0
-#define APOINT_NOTIFY    0x1    /* Item needs to be notified */
-#define APOINT_NOTIFIED  0x2    /* Item was already notified */
-  int state;
+#define APOINT_NOTIFY    0x1	/* Item needs to be notified */
+#define APOINT_NOTIFIED  0x2	/* Item was already notified */
+	int state;
 
-  char *mesg;
-  char *note;
+	char *mesg;
+	char *note;
 };
 
 /* Event definition. */
 struct event {
-  int id;                       /* event identifier */
-  long day;                     /* seconds since 1 jan 1970 */
-  char *mesg;
-  char *note;
+	int id;			/* event identifier */
+	long day;		/* seconds since 1 jan 1970 */
+	char *mesg;
+	char *note;
 };
 
 /* Todo item definition. */
 struct todo {
-  char *mesg;
-  int id;
-  char *note;
-};
-
-/* Number of items in current day. */
-struct day_items_nb {
-  unsigned nb_events;
-  unsigned nb_apoints;
+	char *mesg;
+	int id;
+	char *note;
 };
 
 struct excp {
-  long st;                      /* beggining of the considered day, in seconds */
+	long st;		/* beggining of the considered day, in seconds */
 };
 
 enum recur_type {
-  RECUR_NO,
-  RECUR_DAILY,
-  RECUR_WEEKLY,
-  RECUR_MONTHLY,
-  RECUR_YEARLY,
-  RECUR_TYPES
+	RECUR_NO,
+	RECUR_DAILY,
+	RECUR_WEEKLY,
+	RECUR_MONTHLY,
+	RECUR_YEARLY,
+	RECUR_TYPES
 };
 
 /* To describe an item's repetition. */
 struct rpt {
-  enum recur_type type;         /* repetition type */
-  int freq;                     /* repetition frequence */
-  long until;                   /* ending date for repeated event */
+	enum recur_type type;	/* repetition type */
+	int freq;		/* repetition frequence */
+	long until;		/* ending date for repeated event */
 };
 
 /* Recurrent appointment definition. */
 struct recur_apoint {
-  struct rpt *rpt;              /* information about repetition */
-  llist_t exc;                  /* days when the item should not be repeated */
-  long start;                   /* beggining of the appointment */
-  long dur;                     /* duration of the appointment */
-  char state;                   /* 8 bits to store item state */
-  char *mesg;                   /* appointment description */
-  char *note;                   /* note attached to appointment */
+	struct rpt *rpt;	/* information about repetition */
+	llist_t exc;		/* days when the item should not be repeated */
+	long start;		/* beggining of the appointment */
+	long dur;		/* duration of the appointment */
+	char state;		/* 8 bits to store item state */
+	char *mesg;		/* appointment description */
+	char *note;		/* note attached to appointment */
 };
 
 /* Reccurent event definition. */
 struct recur_event {
-  struct rpt *rpt;              /* information about repetition */
-  llist_t exc;                  /* days when the item should not be repeated */
-  int id;                       /* event type */
-  long day;                     /* day at which event occurs */
-  char *mesg;                   /* event description */
-  char *note;                   /* note attached to event */
+	struct rpt *rpt;	/* information about repetition */
+	llist_t exc;		/* days when the item should not be repeated */
+	int id;			/* event type */
+	long day;		/* day at which event occurs */
+	char *mesg;		/* event description */
+	char *note;		/* note attached to event */
 };
 
 /* Generic pointer data type for appointments and events. */
 union aptev_ptr {
-  struct apoint *apt;
-  struct event *ev;
-  struct recur_apoint *rapt;
-  struct recur_event *rev;
+	struct apoint *apt;
+	struct event *ev;
+	struct recur_apoint *rapt;
+	struct recur_event *rev;
+};
+
+/* Available types of items. */
+enum day_item_type {
+	DAY_HEADING = 1,
+	RECUR_EVNT,
+	EVNT,
+	DAY_SEPARATOR,
+	RECUR_APPT,
+	APPT
 };
 
 /* Generic item description (to hold appointments, events...). */
 struct day_item {
-  int type;                     /* (recursive or normal) event or appointment */
-  long start;                   /* start time of the repetition occurrence */
-  union aptev_ptr item;         /* pointer to the actual item */
+	enum day_item_type type;
+	long start;
+	union aptev_ptr item;
 };
 
 /* Available view for the calendar panel. */
 enum {
-  CAL_MONTH_VIEW,
-  CAL_WEEK_VIEW,
-  CAL_VIEWS
+	CAL_MONTH_VIEW,
+	CAL_WEEK_VIEW,
+	CAL_VIEWS
 };
 
 struct notify_app {
-  long time;
-  int got_app;
-  char *txt;
-  char state;
-  pthread_mutex_t mutex;
+	long time;
+	int got_app;
+	char *txt;
+	char state;
+	pthread_mutex_t mutex;
 };
 
 struct io_file {
-  FILE *fd;
-  char name[BUFSIZ];
+	FILE *fd;
+	char name[BUFSIZ];
 };
 
 /* Available keys. */
 enum key {
-  KEY_GENERIC_CANCEL,
-  KEY_GENERIC_SELECT,
-  KEY_GENERIC_CREDITS,
-  KEY_GENERIC_HELP,
-  KEY_GENERIC_QUIT,
-  KEY_GENERIC_SAVE,
-  KEY_GENERIC_COPY,
-  KEY_GENERIC_PASTE,
-  KEY_GENERIC_CHANGE_VIEW,
-  KEY_GENERIC_IMPORT,
-  KEY_GENERIC_EXPORT,
-  KEY_GENERIC_GOTO,
-  KEY_GENERIC_OTHER_CMD,
-  KEY_GENERIC_CONFIG_MENU,
-  KEY_GENERIC_REDRAW,
-  KEY_GENERIC_ADD_APPT,
-  KEY_GENERIC_ADD_TODO,
-  KEY_GENERIC_PREV_DAY,
-  KEY_GENERIC_NEXT_DAY,
-  KEY_GENERIC_PREV_WEEK,
-  KEY_GENERIC_NEXT_WEEK,
-  KEY_GENERIC_PREV_MONTH,
-  KEY_GENERIC_NEXT_MONTH,
-  KEY_GENERIC_PREV_YEAR,
-  KEY_GENERIC_NEXT_YEAR,
-  KEY_GENERIC_SCROLL_DOWN,
-  KEY_GENERIC_SCROLL_UP,
-  KEY_GENERIC_GOTO_TODAY,
+	KEY_GENERIC_CANCEL,
+	KEY_GENERIC_SELECT,
+	KEY_GENERIC_CREDITS,
+	KEY_GENERIC_HELP,
+	KEY_GENERIC_QUIT,
+	KEY_GENERIC_SAVE,
+	KEY_GENERIC_COPY,
+	KEY_GENERIC_PASTE,
+	KEY_GENERIC_CHANGE_VIEW,
+	KEY_GENERIC_IMPORT,
+	KEY_GENERIC_EXPORT,
+	KEY_GENERIC_GOTO,
+	KEY_GENERIC_OTHER_CMD,
+	KEY_GENERIC_CONFIG_MENU,
+	KEY_GENERIC_REDRAW,
+	KEY_GENERIC_ADD_APPT,
+	KEY_GENERIC_ADD_TODO,
+	KEY_GENERIC_PREV_DAY,
+	KEY_GENERIC_NEXT_DAY,
+	KEY_GENERIC_PREV_WEEK,
+	KEY_GENERIC_NEXT_WEEK,
+	KEY_GENERIC_PREV_MONTH,
+	KEY_GENERIC_NEXT_MONTH,
+	KEY_GENERIC_PREV_YEAR,
+	KEY_GENERIC_NEXT_YEAR,
+	KEY_GENERIC_SCROLL_DOWN,
+	KEY_GENERIC_SCROLL_UP,
+	KEY_GENERIC_GOTO_TODAY,
+	KEY_GENERIC_CMD,
 
-  KEY_MOVE_RIGHT,
-  KEY_MOVE_LEFT,
-  KEY_MOVE_DOWN,
-  KEY_MOVE_UP,
-  KEY_START_OF_WEEK,
-  KEY_END_OF_WEEK,
-  KEY_ADD_ITEM,
-  KEY_DEL_ITEM,
-  KEY_EDIT_ITEM,
-  KEY_VIEW_ITEM,
-  KEY_PIPE_ITEM,
-  KEY_FLAG_ITEM,
-  KEY_REPEAT_ITEM,
-  KEY_EDIT_NOTE,
-  KEY_VIEW_NOTE,
-  KEY_RAISE_PRIORITY,
-  KEY_LOWER_PRIORITY,
+	KEY_MOVE_RIGHT,
+	KEY_MOVE_LEFT,
+	KEY_MOVE_DOWN,
+	KEY_MOVE_UP,
+	KEY_START_OF_WEEK,
+	KEY_END_OF_WEEK,
+	KEY_ADD_ITEM,
+	KEY_DEL_ITEM,
+	KEY_EDIT_ITEM,
+	KEY_VIEW_ITEM,
+	KEY_PIPE_ITEM,
+	KEY_FLAG_ITEM,
+	KEY_REPEAT_ITEM,
+	KEY_EDIT_NOTE,
+	KEY_VIEW_NOTE,
+	KEY_RAISE_PRIORITY,
+	KEY_LOWER_PRIORITY,
 
-  NBKEYS,
-  KEY_UNDEF
+	NBKEYS,
+	KEY_UNDEF
 };
 
 /* To describe a key binding. */
 struct binding {
-  char *label;
-  enum key action;
+	char *label;
+	enum key action;
 };
 
 #define FLAG_CAL (1 << CAL)
@@ -485,122 +493,139 @@ struct binding {
   pthread_cleanup_pop(0);
 
 enum ui_mode {
-  UI_CURSES,
-  UI_CMDLINE,
-  UI_MODES
+	UI_CURSES,
+	UI_CMDLINE,
+	UI_MODES
 };
 
 /* Generic window structure. */
 struct window {
-  WINDOW *p;                    /* pointer to window */
-  unsigned w;                   /* width */
-  unsigned h;                   /* height */
-  int x;                        /* x position */
-  int y;                        /* y position */
+	WINDOW *p;		/* pointer to window */
+	unsigned w;		/* width */
+	unsigned h;		/* height */
+	int x;			/* x position */
+	int y;			/* y position */
 };
 
 /* Generic scrolling window structure. */
 struct scrollwin {
-  struct window win;
-  struct window pad;
-  unsigned first_visible_line;
-  unsigned total_lines;
-  const char *label;
+	WINDOW *win;
+	WINDOW *inner;
+	int y;
+	int x;
+	int h;
+	int w;
+	unsigned line_off;
+	unsigned line_num;
+	const char *label;
+};
+
+/* Generic list box structure. */
+enum listbox_row_type {
+	LISTBOX_ROW_TEXT,
+	LISTBOX_ROW_CAPTION
+};
+
+typedef enum listbox_row_type (*listbox_fn_item_type_t) (int, void *);
+typedef int (*listbox_fn_item_height_t) (int, void *);
+typedef void (*listbox_fn_draw_item_t) (int, WINDOW *, int, int, void *);
+
+struct listbox {
+	struct scrollwin sw;
+	unsigned item_count;
+	int item_sel;
+	listbox_fn_item_type_t fn_type;
+	enum listbox_row_type *type;
+	listbox_fn_item_height_t fn_height;
+	unsigned *ch;
+	listbox_fn_draw_item_t fn_draw;
+	void *cb_data;
 };
 
 /* Pad structure to handle scrolling. */
 struct pad {
-  int width;
-  int length;
-  int first_onscreen;           /* first line to be displayed inside window */
-  WINDOW *ptrwin;               /* pointer to the pad window */
+	int width;
+	int length;
+	int first_onscreen;	/* first line to be displayed inside window */
+	WINDOW *ptrwin;		/* pointer to the pad window */
 };
 
 /* Notification bar definition. */
 struct nbar {
-  unsigned show;                /* display or hide the notify-bar */
-  int cntdwn;                   /* warn when time left before next app
-                                   becomes lesser than cntdwn */
-  char datefmt[BUFSIZ];         /* format for displaying date */
-  char timefmt[BUFSIZ];         /* format for displaying time */
-  char cmd[BUFSIZ];             /* notification command */
-  const char *shell;            /* user shell to launch notif. cmd */
-  unsigned notify_all;          /* notify all appointments */
-  pthread_mutex_t mutex;
-};
-
-/* Available types of items. */
-enum item_type {
-  RECUR_EVNT = 1,
-  EVNT,
-  RECUR_APPT,
-  APPT,
-  MAX_TYPES = APPT
+	unsigned show;		/* display or hide the notify-bar */
+	int cntdwn;		/* warn when time left before next app
+				   becomes lesser than cntdwn */
+	char datefmt[BUFSIZ];	/* format for displaying date */
+	char timefmt[BUFSIZ];	/* format for displaying time */
+	char cmd[BUFSIZ];	/* notification command */
+	const char *shell;	/* user shell to launch notif. cmd */
+	unsigned notify_all;	/* notify all appointments */
+	pthread_mutex_t mutex;
 };
 
 /* Return codes for the getstring() function. */
 enum getstr {
-  GETSTRING_VALID,
-  GETSTRING_ESC,                /* user pressed escape to cancel editing. */
-  GETSTRING_RET                 /* return was pressed without entering any text. */
+	GETSTRING_VALID,
+	GETSTRING_ESC,		/* user pressed escape to cancel editing. */
+	GETSTRING_RET		/* return was pressed without entering any text. */
 };
 
 /* Week days. */
 enum wday {
-  SUNDAY,
-  MONDAY,
-  TUESDAY,
-  WEDNESDAY,
-  THURSDAY,
-  FRIDAY,
-  SATURDAY,
-  WDAYS
+	SUNDAY,
+	MONDAY,
+	TUESDAY,
+	WEDNESDAY,
+	THURSDAY,
+	FRIDAY,
+	SATURDAY,
+	WDAYS
 };
 
 /* Possible movements inside calendar. */
 enum move {
-  DAY_PREV,
-  DAY_NEXT,
-  WEEK_PREV,
-  WEEK_NEXT,
-  WEEK_START,
-  WEEK_END,
-  MONTH_PREV,
-  MONTH_NEXT,
-  YEAR_PREV,
-  YEAR_NEXT
+	DAY_PREV,
+	DAY_NEXT,
+	WEEK_PREV,
+	WEEK_NEXT,
+	WEEK_START,
+	WEEK_END,
+	MONTH_PREV,
+	MONTH_NEXT,
+	YEAR_PREV,
+	YEAR_NEXT
 };
 
 /* Available color pairs. */
 enum {
-  COLR_RED = 1,
-  COLR_GREEN,
-  COLR_YELLOW,
-  COLR_BLUE,
-  COLR_MAGENTA,
-  COLR_CYAN,
-  COLR_DEFAULT,
-  COLR_HIGH,
-  COLR_CUSTOM
+	COLR_RED = 1,
+	COLR_GREEN,
+	COLR_YELLOW,
+	COLR_BLUE,
+	COLR_MAGENTA,
+	COLR_CYAN,
+	COLR_DEFAULT,
+	COLR_HIGH,
+	COLR_CUSTOM
 };
 
 /* Available import types. */
 enum import_type {
-  IO_IMPORT_ICAL,
-  IO_IMPORT_NBTYPES
+	IO_IMPORT_ICAL,
+	IO_IMPORT_NBTYPES
 };
 
 /* Available export types. */
 enum export_type {
-  IO_EXPORT_ICAL,
-  IO_EXPORT_PCAL,
-  IO_EXPORT_NBTYPES
+	IO_EXPORT_ICAL,
+	IO_EXPORT_PCAL,
+	IO_EXPORT_NBTYPES
 };
 
 /* To customize the display when saving data. */
 enum save_display {
-  IO_SAVE_DISPLAY_BAR,
-  IO_SAVE_DISPLAY_NONE
+	IO_SAVE_DISPLAY_BAR,
+	IO_SAVE_DISPLAY_NONE
 };
 
 /* apoint.c */
@@ -610,49 +635,42 @@ struct apoint *apoint_dup(struct apoint *);
 void apoint_free(struct apoint *);
 void apoint_llist_init(void);
 void apoint_llist_free(void);
-void apoint_hilt_set(int);
-void apoint_hilt_decrease(int);
-void apoint_hilt_increase(int);
-int apoint_hilt(void);
 struct apoint *apoint_new(char *, char *, long, long, char);
 unsigned apoint_inday(struct apoint *, long *);
 void apoint_sec2str(struct apoint *, long, char *, char *);
 void apoint_write(struct apoint *, FILE *);
 struct apoint *apoint_scan(FILE *, struct tm, struct tm, char, char *);
 void apoint_delete(struct apoint *);
-void apoint_scroll_pad_down(int, int);
-void apoint_scroll_pad_up(int);
 struct notify_app *apoint_check_next(struct notify_app *, long);
 void apoint_switch_notify(struct apoint *);
-void apoint_update_panel(int);
 void apoint_paste_item(struct apoint *, long);
 
 /* args.c */
 int parse_args(int, char **);
 
 /* calendar.c */
-void calendar_view_next(void);
-void calendar_view_prev(void);
-void calendar_set_view(int);
-int calendar_get_view(void);
-void calendar_start_date_thread(void);
-void calendar_stop_date_thread(void);
-void calendar_set_current_date(void);
-void calendar_set_first_day_of_week(enum wday);
-void calendar_change_first_day_of_week(void);
-unsigned calendar_week_begins_on_monday(void);
-void calendar_store_current_date(struct date *);
-void calendar_init_slctd_day(void);
-struct date *calendar_get_slctd_day(void);
-long calendar_get_slctd_day_sec(void);
-void calendar_monthly_view_cache_set_invalid(void);
-void calendar_update_panel(struct window *);
-void calendar_goto_today(void);
-void calendar_change_day(int);
-void calendar_move(enum move, int);
-long calendar_start_of_year(void);
-long calendar_end_of_year(void);
-const char *calendar_get_pom(time_t);
+void ui_calendar_view_next(void);
+void ui_calendar_view_prev(void);
+void ui_calendar_set_view(int);
+int ui_calendar_get_view(void);
+void ui_calendar_start_date_thread(void);
+void ui_calendar_stop_date_thread(void);
+void ui_calendar_set_current_date(void);
+void ui_calendar_set_first_day_of_week(enum wday);
+void ui_calendar_change_first_day_of_week(void);
+unsigned ui_calendar_week_begins_on_monday(void);
+void ui_calendar_store_current_date(struct date *);
+void ui_calendar_init_slctd_day(void);
+struct date *ui_calendar_get_slctd_day(void);
+long ui_calendar_get_slctd_day_sec(void);
+void ui_calendar_monthly_view_cache_set_invalid(void);
+void ui_calendar_update_panel(void);
+void ui_calendar_goto_today(void);
+void ui_calendar_change_day(int);
+void ui_calendar_move(enum move, int);
+long ui_calendar_start_of_year(void);
+long ui_calendar_end_of_year(void);
+const char *ui_calendar_get_pom(time_t);
 
 /* config.c */
 
@@ -675,7 +693,7 @@ void custom_keys_config(void);
 void custom_config_main(void);
 
 /* day.c */
-void day_free_list(void);
+void day_free_vector(void);
 char *day_item_get_mesg(struct day_item *);
 char *day_item_get_note(struct day_item *);
 void day_item_erase_note(struct day_item *);
@@ -683,18 +701,19 @@ long day_item_get_duration(struct day_item *);
 int day_item_get_state(struct day_item *);
 void day_item_add_exc(struct day_item *, long);
 void day_item_fork(struct day_item *, struct day_item *);
-int day_store_items(long, unsigned *, unsigned *, regex_t *);
-struct day_items_nb *day_process_storage(struct date *, unsigned,
-                                         struct day_items_nb *);
-void day_write_pad(long, int, int, int);
+void day_store_items(long, regex_t *, int);
+void day_process_storage(struct date *, unsigned);
+void day_display_item_date(struct day_item *, WINDOW *, int, long, int, int);
+void day_display_item(struct day_item *, WINDOW *, int, int, int, int);
 void day_write_stdout(long, const char *, const char *, const char *,
-                      const char *);
+		      const char *, int *);
 void day_popup_item(struct day_item *);
 int day_check_if_item(struct date);
 unsigned day_chk_busy_slices(struct date, int, int *);
 struct day_item *day_cut_item(long, int);
 int day_paste_item(struct day_item *, long);
 struct day_item *day_get_item(int);
+unsigned day_item_count(int);
 void day_edit_note(struct day_item *, const char *);
 void day_view_note(struct day_item *, const char *);
 void day_item_switch_notify(struct day_item *);
@@ -717,33 +736,18 @@ struct event *event_scan(FILE *, struct tm, int, char *);
 void event_delete(struct event *);
 void event_paste_item(struct event *, long);
 
-/* help.c */
-void help_wins_init(struct scrollwin *, int, int, int, int);
-void help_screen(void);
-
 /* getstring.c */
 enum getstr getstring(WINDOW *, char *, int, int, int);
 int updatestring(WINDOW *, char **, int, int);
 
+/* help.c */
+int display_help(const char *);
+
 /* ical.c */
 void ical_import_data(FILE *, FILE *, unsigned *, unsigned *, unsigned *,
-                      unsigned *, unsigned *);
+		      unsigned *, unsigned *);
 void ical_export_data(FILE *);
 
-/* interaction.c */
-void interact_day_item_add(void);
-void interact_day_item_delete(unsigned *, unsigned *, unsigned);
-void interact_day_item_edit(void);
-void interact_day_item_pipe(void);
-void interact_day_item_repeat(void);
-void interact_day_item_cut_free(unsigned);
-void interact_day_item_copy(unsigned *, unsigned *, unsigned);
-void interact_day_item_paste(unsigned *, unsigned *, unsigned);
-void interact_todo_add(void);
-void interact_todo_delete(void);
-void interact_todo_edit(void);
-void interact_todo_pipe(void);
-
 /* io.c */
 unsigned io_fprintln(const char *, const char *, ...);
 void io_init(const char *, const char *);
@@ -756,7 +760,8 @@ void io_load_app(void);
 void io_load_todo(void);
 void io_load_keys(const char *);
 int io_check_dir(const char *);
-unsigned io_file_exist(const char *);
+unsigned io_dir_exists(const char *);
+unsigned io_file_exists(const char *);
 int io_check_file(const char *);
 int io_check_data_files(void);
 void io_startup_screen(int);
@@ -790,12 +795,26 @@ const char *keys_action_firstkey(enum key);
 const char *keys_action_nkey(enum key, int);
 char *keys_action_allkeys(enum key);
 void keys_display_bindings_bar(WINDOW *, struct binding *[], int, int,
-                               int, struct binding *);
+			       int, struct binding *);
 void keys_popup_info(enum key);
 void keys_save_bindings(FILE *);
 int keys_check_missing_bindings(void);
 void keys_fill_missing(void);
 
+/* listbox.c */
+void listbox_init(struct listbox *, int, int, int, int, const char *,
+		  listbox_fn_item_type_t, listbox_fn_item_height_t,
+		  listbox_fn_draw_item_t);
+void listbox_delete(struct listbox *);
+void listbox_resize(struct listbox *, int, int, int, int);
+void listbox_set_cb_data(struct listbox *, void *);
+void listbox_load_items(struct listbox *, int);
+void listbox_draw_deco(struct listbox *, int);
+void listbox_display(struct listbox *);
+int listbox_get_sel(struct listbox *);
+void listbox_set_sel(struct listbox *, unsigned);
+void listbox_sel_move(struct listbox *, int);
+
 /* mem.c */
 void *xmalloc(size_t);
 void *xcalloc(size_t, size_t);
@@ -876,23 +895,25 @@ void recur_apoint_llist_init(void);
 void recur_apoint_llist_free(void);
 void recur_event_llist_free(void);
 struct recur_apoint *recur_apoint_new(char *, char *, long, long, char,
-                                      int, int, long, llist_t *);
+				      int, int, long, llist_t *);
 struct recur_event *recur_event_new(char *, char *, long, int, int, int,
-                                    long, llist_t *);
+				    long, llist_t *);
 char recur_def2char(enum recur_type);
 int recur_char2def(char);
 struct recur_apoint *recur_apoint_scan(FILE *, struct tm, struct tm,
-                                       char, int, struct tm, char *,
-                                       llist_t *, char);
+				       char, int, struct tm, char *,
+				       llist_t *, char);
 struct recur_event *recur_event_scan(FILE *, struct tm, int, char,
-                                     int, struct tm, char *, llist_t *);
+				     int, struct tm, char *, llist_t *);
 void recur_apoint_write(struct recur_apoint *, FILE *);
 void recur_event_write(struct recur_event *, FILE *);
 void recur_save_data(FILE *);
 unsigned recur_item_find_occurrence(long, long, llist_t *, int,
-                                    int, long, long, unsigned *);
-unsigned recur_apoint_find_occurrence(struct recur_apoint *, long, unsigned *);
-unsigned recur_event_find_occurrence(struct recur_event *, long, unsigned *);
+				    int, long, long, unsigned *);
+unsigned recur_apoint_find_occurrence(struct recur_apoint *, long,
+				      unsigned *);
+unsigned recur_event_find_occurrence(struct recur_event *, long,
+				     unsigned *);
 unsigned recur_item_inday(long, long, llist_t *, int, int, long, long);
 unsigned recur_apoint_inday(struct recur_apoint *, long *);
 unsigned recur_event_inday(struct recur_event *, long *);
@@ -901,7 +922,8 @@ void recur_apoint_add_exc(struct recur_apoint *, long);
 void recur_event_erase(struct recur_event *);
 void recur_apoint_erase(struct recur_apoint *);
 void recur_exc_scan(llist_t *, FILE *);
-struct notify_app *recur_apoint_check_next(struct notify_app *, long, long);
+struct notify_app *recur_apoint_check_next(struct notify_app *, long,
+					   long);
 void recur_apoint_switch_notify(struct recur_apoint *);
 void recur_event_paste_item(struct recur_event *, long);
 void recur_apoint_paste_item(struct recur_apoint *, long);
@@ -915,30 +937,57 @@ void sigs_unignore(void);
 /* todo.c */
 extern llist_t todolist;
 struct todo *todo_get_item(int);
-void todo_hilt_set(int);
-void todo_hilt_decrease(int);
-void todo_hilt_increase(int);
-int todo_hilt(void);
-int todo_nb(void);
-void todo_set_nb(int);
-void todo_set_first(int);
-void todo_first_increase(int);
-void todo_first_decrease(int);
-int todo_hilt_pos(void);
-char *todo_saved_mesg(void);
 struct todo *todo_add(char *, int, char *);
 void todo_write(struct todo *, FILE *);
 void todo_delete_note(struct todo *);
 void todo_delete(struct todo *);
 void todo_flag(struct todo *);
-void todo_chg_priority(struct todo *, int);
-void todo_update_panel(int);
+int todo_get_position(struct todo *);
 void todo_edit_note(struct todo *, const char *);
 void todo_view_note(struct todo *, const char *);
 void todo_free(struct todo *);
 void todo_init_list(void);
 void todo_free_list(void);
 
+/* ui-day.c */
+void ui_day_item_add(void);
+void ui_day_item_delete(unsigned);
+void ui_day_item_edit(void);
+void ui_day_item_pipe(void);
+void ui_day_item_repeat(void);
+void ui_day_item_cut_free(unsigned);
+void ui_day_item_copy(unsigned);
+void ui_day_item_paste(unsigned);
+void ui_day_load_items(void);
+void ui_day_sel_reset(void);
+void ui_day_sel_move(int);
+void ui_day_draw(int, WINDOW *, int, int, void *);
+enum listbox_row_type ui_day_row_type(int, void *);
+int ui_day_height(int, void *);
+void ui_day_update_panel(int);
+void ui_day_popup_item(void);
+void ui_day_flag(void);
+void ui_day_view_note(void);
+void ui_day_edit_note(void);
+
+/* ui-todo.c */
+void ui_todo_add(void);
+void ui_todo_delete(void);
+void ui_todo_edit(void);
+void ui_todo_pipe(void);
+void ui_todo_draw(int, WINDOW *, int, int, void *);
+enum listbox_row_type ui_todo_row_type(int, void *);
+int ui_todo_height(int, void *);
+void ui_todo_load_items(void);
+void ui_todo_sel_reset(void);
+void ui_todo_sel_move(int);
+void ui_todo_update_panel(int);
+void ui_todo_chg_priority(int);
+void ui_todo_popup_item(void);
+void ui_todo_flag(void);
+void ui_todo_view_note(void);
+void ui_todo_edit_note(void);
+
 /* utf8.c */
 int utf8_width(char *);
 int utf8_strwidth(char *);
@@ -971,14 +1020,15 @@ void item_in_popup(const char *, const char *, const char *, const char *);
 long get_today(void);
 long now(void);
 char *nowstr(void);
-long mystrtol(const char *);
 void print_bool_option_incolor(WINDOW *, unsigned, int, int);
 const char *get_tempdir(void);
 char *new_tempfile(const char *, int);
-int parse_date(const char *, enum datefmt, int *, int *, int *, struct date *);
+int check_date(unsigned, unsigned, unsigned);
+int parse_date(const char *, enum datefmt, int *, int *, int *,
+	       struct date *);
+int check_time(unsigned, unsigned);
 int parse_time(const char *, unsigned *, unsigned *);
 int parse_duration(const char *, unsigned *);
-void str_toupper(char *);
 void file_close(FILE *, const char *);
 void psleep(unsigned);
 int fork_exec(int *, int *, const char *, const char *const *);
@@ -987,7 +1037,8 @@ int child_wait(int *, int *, int);
 void press_any_key(void);
 void print_apoint(const char *, long, struct apoint *);
 void print_event(const char *, long, struct event *);
-void print_recur_apoint(const char *, long, unsigned, struct recur_apoint *);
+void print_recur_apoint(const char *, long, unsigned,
+			struct recur_apoint *);
 void print_recur_event(const char *, long, struct recur_event *);
 void print_todo(const char *, struct todo *);
 
@@ -1019,6 +1070,9 @@ void vars_init(void);
 
 /* wins.c */
 extern struct window win[NBWINS];
+extern struct scrollwin sw_cal;
+extern struct listbox lb_apt;
+extern struct listbox lb_todo;
 unsigned wins_nbar_lock(void);
 void wins_nbar_unlock(void);
 void wins_nbar_cleanup(void *);
@@ -1039,18 +1093,25 @@ enum win wins_slctd(void);
 void wins_slctd_set(enum win);
 void wins_slctd_next(void);
 void wins_init(void);
-void wins_scrollwin_init(struct scrollwin *);
+void wins_scrollwin_init(struct scrollwin *, int, int, int, int, const char *);
+void wins_scrollwin_resize(struct scrollwin *, int, int, int, int);
+void wins_scrollwin_set_linecount(struct scrollwin *, unsigned);
 void wins_scrollwin_delete(struct scrollwin *);
+void wins_scrollwin_draw_deco(struct scrollwin *, int);
 void wins_scrollwin_display(struct scrollwin *);
 void wins_scrollwin_up(struct scrollwin *, int);
 void wins_scrollwin_down(struct scrollwin *, int);
-void wins_reinit(void);
-void wins_reinit_panels(void);
+int wins_scrollwin_is_visible(struct scrollwin *, unsigned);
+void wins_scrollwin_ensure_visible(struct scrollwin *, unsigned);
+void wins_scrollwin_set_lower(struct scrollwin *, unsigned);
+void wins_resize(void);
+void wins_resize_panels(void);
 void wins_show(WINDOW *, const char *);
 void wins_get_config(void);
 void wins_update_border(int);
 void wins_update_panels(int);
 void wins_update(int);
+void wins_reset_noupdate(void);
 void wins_reset(void);
 void wins_prepare_external(void);
 void wins_unprepare_external(void);
